/// <reference types="webpack" />
import wp = require("webpack");
import { SourceMapConsumer } from 'source-map';
export interface Option {
    defaultLanguage: string;
    /**
     * languages to emit
     */
    languages: string[];
    defaultNamespace?: string;
    namespaces?: string[];
    /**
     * Scanning function name
     *
     * @default "__"
     */
    functionName?: string;
    resourcePath: string;
    /**
     * save missing translations to...
     */
    pathToSaveMissing: string;
    /**
     * change emit path
     * if this value is not set, emit to resourcePath
     */
    outPath?: string;
}
export interface InternalOption extends Option {
    defaultNamespace: string;
    namespaces: string[];
    outPath: string;
}
export declare type CollectedKeys = {
    [language: string]: {
        [namespace: string]: {
            [key: string]: {
                [module: string]: [number, number];
            };
        };
    };
};
export default class I18nextPlugin {
    protected compilation: wp.Compilation;
    protected option: InternalOption;
    protected context: string;
    protected missingKeys: CollectedKeys;
    protected startTime: number;
    protected prevTimestamps: {
        [file: string]: number;
    };
    protected sourceMaps: {
        [key: string]: SourceMapConsumer;
    };
    protected missingDirInitialized: boolean;
    constructor(option: Option);
    apply(compiler: wp.Compiler): void;
    protected initMissingDir(): Promise<void>;
    protected onEmit(compilation: wp.Compilation, callback: (err?: Error) => void): Promise<void>;
    protected readonly outPath: string;
    protected onAfterEmit(compilation: wp.Compilation, callback: (err?: Error) => void): Promise<void>;
    protected argsToSource(sourceMap: SourceMapConsumer, arg: wp.Expression): Promise<string | null>;
    protected static onTranslateFunctionCall(this: wp.Parser, plugin: I18nextPlugin, expr: wp.Expression): void;
    protected onKeyMissing(lng: string, ns: string, key: string, pos: [string, number, number]): void;
    protected warningOnCompilation(msg: string): void;
}
